@@ -32,47 +32,37 @@ sub read_db_config_files {
 }
 
 
-my $prev_plugin = '';
-my $db_opt;
-
-
 sub attributes {
-    my ( $sf, $db ) = @_;
+    my ( $sf, $db, $db_opt ) = @_;
     my $plui = App::DBBrowser::DB->new( $sf->{i}, $sf->{o} );
     my $plugin = $sf->{i}{plugin};
-    if ( $prev_plugin ne $plugin ) {
-        $db_opt = undef;
-        $prev_plugin = $plugin;
-    }
-    # attributes added by hand to the config file: attribues are
-    # only used if they have entries in the set_attributes method
-    $db_opt //= $sf->read_db_config_files();
+    # attributes added by hand to the config file:
+    # added attribues are only used if they have entries in the set_attributes method
     my $attributes = $plui->set_attributes();
-    my $attrs = {};
-    for my $attr ( @$attributes )  {
-        my $name = $attr->{name};
-        $attrs->{$name} = $db_opt->{$db//''}{$name} // $db_opt->{$plugin}{$name} // $attr->{values}[$attr->{default}];
+    my $prepared_attrs = {};
+    for my $attribute ( @$attributes )  {
+        my $name = $attribute->{name};
+        my $idx = $db_opt->{$db//''}{$name} // $db_opt->{$plugin}{$name} // $attribute->{default};
+        $prepared_attrs->{$name} = $attribute->{values}[$idx];
+        if ( $prepared_attrs->{$name} =~ /^(\d+)\s/ ) { # e.g.: '5 DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK'
+            $prepared_attrs->{$name} = $1;
+        }
     }
-    return $attrs;
+    return $prepared_attrs;
 
 }
 
 sub login_data {
-    my ( $sf, $db ) = @_;
+    my ( $sf, $db, $db_opt ) = @_;
     my $plui = App::DBBrowser::DB->new( $sf->{i}, $sf->{o} );
     my $plugin = $sf->{i}{plugin};
-    if ( $prev_plugin ne $plugin ) {
-        $db_opt = undef;
-        $prev_plugin = $plugin;
-    }
-    $db_opt //= $sf->read_db_config_files();
     my $arg = $plui->read_arguments();
     my $data = {};
 
     for my $item ( @$arg ) {
         my $name = $item->{name};
         my $secret = $item->{secret};
-        my $field_is_required = $db_opt->{$db//''}{'field_' . $name} // $db_opt->{$plugin}{'field_' . $name} // 1; # set to required (1) if undefined
+        my $field_is_required = $db_opt->{$db//''}{'field_' . $name} // $db_opt->{$plugin}{'field_' . $name} // 1; # set to "required" (1) if undefined
         if ( $field_is_required ) {
             if ( exists $sf->{i}{login_error} && $sf->{i}{login_error} ) {
                 $data->{$name}{default} = undef; # if a login error occured, the user has to enter the arguments by hand
@@ -89,14 +79,9 @@ sub login_data {
 
 
 sub enabled_env_vars {
-    my ( $sf, $db ) = @_;
+    my ( $sf, $db, $db_opt ) = @_;
     my $plui = App::DBBrowser::DB->new( $sf->{i}, $sf->{o} );
     my $plugin = $sf->{i}{plugin};
-    if ( $prev_plugin ne $plugin ) {
-        $db_opt = undef;
-        $prev_plugin = $plugin;
-    }
-    $db_opt //= $sf->read_db_config_files();
     my $env_vars = $plui->env_variables();
     my $enabled_env_vars = {};
     for my $env_var ( @$env_vars ) {
